NativeAdmobOptions class

Constructors

NativeAdmobOptions({bool showMediaContent = true, Color ratingColor = Colors.yellow, NativeTextStyle adLabelTextStyle = const NativeTextStyle(fontSize: 12, color: Colors.white, backgroundColor: Color(0xFFFFCC66)), NativeTextStyle headlineTextStyle = const NativeTextStyle(fontSize: 16, color: Colors.black, backgroundColor: Colors.white), NativeTextStyle advertiserTextStyle = const NativeTextStyle(fontSize: 14, backgroundColor: Colors.white, color: Colors.black), NativeTextStyle bodyTextStyle = const NativeTextStyle(fontSize: 12, backgroundColor: Colors.white, color: Colors.grey), NativeTextStyle storeTextStyle = const NativeTextStyle(fontSize: 12, backgroundColor: Colors.white, color: Colors.black), NativeTextStyle priceTextStyle = const NativeTextStyle(fontSize: 12, backgroundColor: Colors.white, color: Colors.black), NativeTextStyle callToActionStyle = const NativeTextStyle(fontSize: 15, color: Colors.white, backgroundColor: Color(0xFF4CBE99))})
const

Properties

adLabelTextStyle → NativeTextStyle
final
advertiserTextStyle → NativeTextStyle
final
bodyTextStyle → NativeTextStyle
final
callToActionStyle → NativeTextStyle
final
hashCode → int
The hash code for this object.
no setterinherited
headlineTextStyle → NativeTextStyle
final
priceTextStyle → NativeTextStyle
final
ratingColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMediaContent → bool
final
storeTextStyle → NativeTextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited