NativeTextStyle class

Constructors

NativeTextStyle({required double fontSize, required Color color, required Color backgroundColor, bool isVisible = true})
const

Properties

backgroundColor → Color
final
color → Color
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
isVisible → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited